pub enum ApiKeyScope {
WorkflowsRead,
RunsRead,
RunsWrite,
RunsManage,
StatsRead,
Admin,
}Expand description
Permission scope for an API key.
Each scope grants access to a specific set of actions. A key with no scopes has no permissions.
Variants
WorkflowsRead
Read workflow definitions.
RunsRead
Read runs and their steps.
RunsWrite
Create new runs (trigger workflows).
RunsManage
Cancel, approve, reject, retry runs.
StatsRead
Read aggregated statistics.
Admin
Full access to all operations.
Implementations
Sourceimpl ApiKeyScope
impl ApiKeyScope
Sourcepub fn permits(&self, required: &ApiKeyScope) -> bool
pub fn permits(&self, required: &ApiKeyScope) -> bool
Check whether this scope grants the required permission.
Sourcepub fn has_permission(scopes: &[ApiKeyScope], required: &ApiKeyScope) -> bool
pub fn has_permission(scopes: &[ApiKeyScope], required: &ApiKeyScope) -> bool
Check whether a set of scopes grants the required permission.
Sourcepub fn all_non_admin() -> Vec<ApiKeyScope>
pub fn all_non_admin() -> Vec<ApiKeyScope>
All available scopes (excluding admin).